# References

## Method used in SHRY

(reference_canonical_augmentation)=

### Canonical Augmentation

SHRY uses canonical augmentation to generate non-duplicate substitution patterns.

- [B. D. McKay, J. Algorithms 26, 306-324 (1998)](https://doi.org/10.1006/jagm.1997.0898)
- [P. Kaski and P. R. J. Östergård, Classification Algorithms for Codes and Designs (Algorithms and Computation in Mathematics), Springer-Verlag, Berlin, Heidelberg (2006)](https://doi.org/10.1007/3-540-28991-7)

### SHRY Implementation

- [G. I. Prayogo et al., J. Chem. Inf. Model. 62, 2909-2915 (2022)](https://doi.org/10.1021/acs.jcim.2c00389)

## Related Methods

### Orderly Generation

- [R. C. Read, Ann. Discrete Math. 2, 107-120 (1978)](https://doi.org/10.1016/S0167-5060(08)70325-X)

### Crystal Symmetry and Magnetic Space Group (spglib)

- [A. Togo, K. Shinohara, and I. Tanaka, Spglib: a software library for crystal symmetry search, Sci. Technol. Adv. Mater. Methods 4, 2384822 (2024)](https://www.tandfonline.com/doi/full/10.1080/27660400.2024.2384822)
- [A. Togo, K. Shinohara, and I. Tanaka, Implementation strategy of magnetic space group in spglib, Acta Crystallogr. A 79, C224 (2023)](https://journals.iucr.org/a/issues/2023/a2/00/a62492/a62492.pdf)
